aboutsummaryrefslogtreecommitdiffstats
path: root/resources/lib/moment/lang/nn.js
diff options
context:
space:
mode:
Diffstat (limited to 'resources/lib/moment/lang/nn.js')
-rw-r--r--resources/lib/moment/lang/nn.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/resources/lib/moment/lang/nn.js b/resources/lib/moment/lang/nn.js
index 8c1510855db8..e479b4582cc9 100644
--- a/resources/lib/moment/lang/nn.js
+++ b/resources/lib/moment/lang/nn.js
@@ -1,5 +1,5 @@
// moment.js language configuration
// language : norwegian nynorsk (nn)
// author : https://github.com/mechuwind
(function (factory) {
@@ -11,7 +11,7 @@
factory(window.moment); // Browser global
}
}(function (moment) {
- return moment.lang('nn', {
+ return moment.defineLocale('nn', {
months : "januar_februar_mars_april_mai_juni_juli_august_september_oktober_november_desember".split("_"),
monthsShort : "jan_feb_mar_apr_mai_jun_jul_aug_sep_okt_nov_des".split("_"),
weekdays : "sundag_måndag_tysdag_onsdag_torsdag_fredag_laurdag".split("_"),
@@ -1,5 +1,5 @@
-// moment.js language configuration
-// language : norwegian nynorsk (nn)
+// moment.js locale configuration
+// locale : norwegian nynorsk (nn)
// author : https://github.com/mechuwind
(function (factory) {